Index: include/core/SkTArray.h |
=================================================================== |
--- include/core/SkTArray.h (revision 13896) |
+++ include/core/SkTArray.h (working copy) |
@@ -53,7 +53,7 @@ |
/** When MEM_COPY is true T will be bit copied when moved. |
When MEM_COPY is false, T will be copy constructed / destructed. |
- In all cases T's constructor will be called on allocation, |
+ In all cases T will be default-initialized on allocation, |
and its destructor will be called from this object's destructor. |
*/ |
template <typename T, bool MEM_COPY> class SkTArray { |
@@ -173,7 +173,7 @@ |
bool empty() const { return !fCount; } |
/** |
* Adds 1 new default-constructed T value and returns in by reference. Note |
* the reference only remains valid until the next call that adds or removes |
* elements. |
*/ |
@@ -193,9 +193,9 @@ |
} |
/** |
* Allocates n more default T values, and returns the address of the start |
* of that new range. Note: this address is only valid until the next API |
* call made on the array that might add or remove elements. |
*/ |
T* push_back_n(int n) { |
SkASSERT(n >= 0); |
@@ -173,7 +173,7 @@ |
bool empty() const { return !fCount; } |
/** |
- * Adds 1 new default-constructed T value and returns in by reference. Note |
+ * Adds 1 new default-initialized T value and returns it by reference. Note |
* the reference only remains valid until the next call that adds or removes |
* elements. |
@@ -193,9 +193,9 @@ |
} |
/** |
- * Allocates n more default T values, and returns the address of the start |
- * of that new range. Note: this address is only valid until the next API |
- * call made on the array that might add or remove elements. |
+ * Allocates n more default-initialized T values, and returns the address of |
+ * the start of that new range. Note: this address is only valid until the |
+ * next API call made on the array that might add or remove elements. |
*/ |
T* push_back_n(int n) { |